package bookstorecounterexample;

import java.util.ArrayList;
/**
* <h1>Shopping Cart</h1>
* Class responsible for storing all 
* the items that are selected from the user.
*
* @version 1.0
* @since   2017-07-17
*/
public class ShoppingCart {
	
	private ArrayList<Item> items;
	private float totalCost;
	
	public ShoppingCart(){
		this.items = new ArrayList<Item>();
		this.totalCost = 0;
	}
	
	/**
 	 * Adds an item to the cart
 	 * @param item: item for addition
 	 */
	public void addItem(Item item){
		this.items.add(item);
	}
	
	/**
 	 * Removes the item in the selected position
 	 * @param i: position of item for deletion
 	 */
	public void removeItem(int i){
		this.items.remove(i);
	}
	
	private void computeTotalCost(){
		float cost = 0;
		for(Item item: this.items){
			cost += item.getFinalPrice();
		}
		this.totalCost = cost;
	}
	
	/**
 	 * @return the total cost of selected items
 	 */
	public float getTotalCost(){
		this.computeTotalCost();
		return this.totalCost;
	}
	
	/**
 	 * Displays the details of each item in the
 	 * cart in the console.
 	 */
	public void showDetails(){
		System.out.println("------------------------");
		System.out.println("       CART ITEMS       ");
		System.out.println("------------------------");
		for(Item item: this.items){
			item.showDetails();
		}
		System.out.println("Total cost: " + this.getTotalCost());
	}
}
